@@ -1,3 +1,3 @@
 ## Simple alias to mimic the OpenBUGS script command 
 
-"modelSetWD" <- setwd
+"modelSetWD" <- function(dir) setwd(dir)
